

#nvpl_lapack-config.cmake
#
# Package COMPONENT's defined:
# Integer types:
#  * lp64 - 32-bit Integer interface
#  * ilp64 - 64-bit Integer interface
# Threading types:
#  * seq - Sequential interface
#  * omp - OpenMP threading interface
#
# Imported interface targets provided:
#  * nvpl::lapack_<lp>_<thr> - shared library targets
#
# Output variables set:
#  * nvpl_lapack_INT_TYPES - List of available integer types for <lp> in targets
#  * nvpl_lapack_THREADING_TYPES - List of available threading types for <thr> in targets
#  * nvpl_lapack_VERSION - Version of installed package
#  * nvpl_lapack_BUILD_TYPES - Available CMake BUILD_TYPES found for targets at this location
#  * nvpl_lapack_Fortran_COMPILER_ID - Fortran Compiler ID
#  * nvpl_lapack_INCLUDE_DIR - Location of nvpl_lapack headers
#  * nvpl_lapack_LIBRARY_DIR - Location of nvpl_lapack libraries


set(nvpl_lapack_VERSION 0.3.1)
# build: 279

set(nvpl_lapack_INT_TYPES "lp64;ilp64")
set(nvpl_lapack_THREADING_TYPES "seq;omp")
set(nvpl_lapack_IFACE_OMP_VENDOR "GNU")
set(nvpl_lapack_IFACE_OMP_VENDOR_PREFIX "g")

## Dependencies
include(CMakeFindDependencyMacro)
if(NOT nvpl_blas_FOUND)
    find_dependency(nvpl_blas REQUIRED)
endif()

## Find header and lib directories via known header and lib names
set(_nvpl_lapack_search_header_name nvpl_lapack.h)
set(_nvpl_lapack_search_lib_name libnvpl_lapack_core.so)
get_filename_component(_nvpl_lapack_search_prefix "${CMAKE_CURRENT_LIST_DIR}/../../" ABSOLUTE)

find_path(nvpl_lapack_INCLUDE_DIR
          NAMES ${_nvpl_lapack_search_header_name}
          PATHS ${_nvpl_lapack_search_prefix}
          PATH_SUFFIXES
            ../include
            ../../include # Debian/Ubuntu aarch64
          NO_DEFAULT_PATH
          NO_CACHE) # Set cache variable after path normalization

find_path(nvpl_lapack_LIBRARY_DIR
          NAMES ${_nvpl_lapack_search_lib_name}
          PATHS ${_nvpl_lapack_search_prefix}
          PATH_SUFFIXES lib lib64
          DOC "Location of nvpl_lapack libraries"
          NO_DEFAULT_PATH)

# Check headers and library directories are found
if(NOT EXISTS "${nvpl_lapack_INCLUDE_DIR}")
    message(FATAL_ERROR "Header directory containing file ${_nvpl_lapack_search_header_name} was not found relative to ${CMAKE_CURRENT_LIST_DIR}!")
endif()
if(NOT EXISTS "${nvpl_lapack_LIBRARY_DIR}")
    message(FATAL_ERROR "Library directory containing file ${_nvpl_lapack_search_lib_name} was not found relative to ${CMAKE_CURRENT_LIST_DIR}!")
endif()

# Normalize nvpl_lapack_INCLUDE_DIR and set cache variable
get_filename_component(nvpl_lapack_INCLUDE_DIR "${nvpl_lapack_INCLUDE_DIR}" ABSOLUTE)
set(nvpl_lapack_INCLUDE_DIR ${nvpl_lapack_INCLUDE_DIR} CACHE STRING "Location of nvpl_lapack headers")

unset(_nvpl_lapack_search_header_name)
unset(_nvpl_lapack_search_lib_name)
unset(_nvpl_lapack_search_prefix)

## Targets
if(NOT TARGET nvpl_lapack_core)
    include("${CMAKE_CURRENT_LIST_DIR}/nvpl_lapack-targets.cmake")
    set_target_properties(nvpl_lapack_core PROPERTIES IMPORTED_GLOBAL 1)
endif()

# Find component libraries
foreach(_lp IN LISTS nvpl_lapack_INT_TYPES)
    foreach(_thr IN LISTS nvpl_lapack_THREADING_TYPES)
        if(_thr STREQUAL "omp")
            set(_prefix_thr ${nvpl_lapack_IFACE_OMP_VENDOR_PREFIX}${_thr})
        else()
            set(_prefix_thr ${_thr})
        endif()
        set(_tgt nvpl_lapack_${_lp}_${_prefix_thr})

        # Mark COMPONENTs found
        set(nvpl_lapack_${_lp}_FOUND 1)
        set(nvpl_lapack_${_thr}_FOUND 1)

        # Add namespaced target aliases if not already created
        if(NOT TARGET nvpl::lapack_${_lp}_${_thr})
            set_target_properties(${_tgt} PROPERTIES IMPORTED_GLOBAL 1)
            add_library(nvpl::lapack_${_lp}_${_thr} ALIAS ${_tgt})
            if(TARGET ${_tgt}_static)
                set_target_properties(${_tgt}_static PROPERTIES IMPORTED_GLOBAL 1)
                add_library(nvpl::lapack_${_lp}_${_thr}_static ALIAS ${_tgt}_static)
            endif()
        endif()
    endforeach()
endforeach()

# Cleanup temporary variables and check if components satisfied
unset(_lp)
unset(_prefix_thr)
unset(_thr)
unset(_tgt)
unset(_lang)
check_required_components(nvpl_lapack)

## Report status
if(NOT ${CMAKE_FIND_PACKAGE_NAME}_FIND_QUIETLY)
    set(_components ${nvpl_lapack_INT_TYPES} ${nvpl_lapack_THREADING_TYPES})
    message(STATUS "Found nvpl_lapack: (Version:${nvpl_lapack_VERSION}
                       CMakePackageDir:${CMAKE_CURRENT_LIST_DIR}
                       IncludeDir:${nvpl_lapack_INCLUDE_DIR}
                       LibraryDir:${nvpl_lapack_LIBRARY_DIR}
                       ComponentsFound:[${_components}])")
    unset(_components)
endif()
